local S = homedecor.gettext
local modpath = minetest.get_modpath("building_blocks")

dofile(modpath.."/alias.lua")
dofile(modpath.."/node_stairs.lua")
dofile(modpath.."/others.lua")
dofile(modpath.."/recipes.lua")
